@@ -1,10 +1,12 @@
 /*
   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filtermailmangziptest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "filterimportertest.h"
 #include <MailImporter/FilterMailmanGzip>
 #include <QTest>
@@ -43,7 +45,7 @@ void FilterMAilmangzipTest::canNotImportDataUnknowPath()
     FilterImporterTest *importerTest = new FilterImporterTest(info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(info);
-    filter.importMails(QStringList() << QStringLiteral("/foo/kde/bla/toto/bla.zip"));
+    filter.importMails(QStringList() << u"/foo/kde/bla/toto/bla.zip"_s);
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
 #endif
 }
